# Circle Map Report
### On this page
  * [HOW is it useful?](https://help.sap.com/docs/leanix/ea/circle-map-report#how-is-it-useful?)
  * [Using the Circle Map Report](https://help.sap.com/docs/leanix/ea/circle-map-report#using-the-circle-map-report)
  * [Applying Filter](https://help.sap.com/docs/leanix/ea/circle-map-report#applying-filter)
  * [Editing in the Report](https://help.sap.com/docs/leanix/ea/circle-map-report#editing-in-the-report)


The Circle Map report shows the interconnections between the Interfaces and Applications in an organization's system architecture. You can group Applications alphabetically or by Business Capabilities to visualize dependencies between them and easily identify provider or consumer applications and analyze their impacts. It is particularly helpful in identifying potential risks while transforming legacy systems.
You can see it as a visual repository of interfaces that helps you track changes and updates in application dependencies in real time. To use the Interface Circle Map report, ensure provider and consumer applications are documented in Interface Fact Sheets.
![View of the Interface Circle Map](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27550a7d7a44101495859b047ac32044_LowRes.png)
View of the Interface Circle Map
